==> haskell-jira-wiki-markup-1.4.0-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jira-wiki-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 jira-wiki-markup
version:              1.4.0
visibility:           public
id:                   jira-wiki-markup-1.4.0-9VtEXyxKfZD2VC0DBx9vX1
key:                  jira-wiki-markup-1.4.0-9VtEXyxKfZD2VC0DBx9vX1
license:              MIT
copyright:            © 2019–2021 Albert Krewinkel
maintainer:           tarleb@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/jira-wiki-markup
synopsis:             Handle Jira wiki markup
description:
    Parse jira wiki text into an abstract syntax tree for easy
    transformation to other formats.

category:             Text
abi:                  aefcdbbb170e577d9bb7eb1bfc6f1db4
exposed:              True
exposed-modules:
    Text.Jira.Markup Text.Jira.Parser Text.Jira.Parser.Block
    Text.Jira.Parser.Core Text.Jira.Parser.Inline
    Text.Jira.Parser.PlainText Text.Jira.Parser.Shared
    Text.Jira.Printer

import-dirs:          /usr/lib/ghc-9.0.2/site-local/jira-wiki-markup-1.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/jira-wiki-markup-1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jira-wiki-markup
hs-libraries:         HSjira-wiki-markup-1.4.0-9VtEXyxKfZD2VC0DBx9vX1
depends:              base-4.15.1.0 mtl-2.2.2 parsec-3.1.14.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-jira-wiki-markup/html/jira-wiki-markup.haddock

haddock-html:         /usr/share/doc/haskell-jira-wiki-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jira-wiki-markup-1.4.0-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jira-wiki-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 jira-wiki-markup
version:              1.4.0
visibility:           public
id:                   jira-wiki-markup-1.4.0-39eTg3CIs9iFOsMMa3t1aY
key:                  jira-wiki-markup-1.4.0-39eTg3CIs9iFOsMMa3t1aY
license:              MIT
copyright:            © 2019–2021 Albert Krewinkel
maintainer:           tarleb@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/jira-wiki-markup
synopsis:             Handle Jira wiki markup
description:
    Parse jira wiki text into an abstract syntax tree for easy
    transformation to other formats.

category:             Text
abi:                  50b7868c34215affa1ad626ad64fce14
exposed:              True
exposed-modules:
    Text.Jira.Markup Text.Jira.Parser Text.Jira.Parser.Block
    Text.Jira.Parser.Core Text.Jira.Parser.Inline
    Text.Jira.Parser.PlainText Text.Jira.Parser.Shared
    Text.Jira.Printer

import-dirs:          /usr/lib/ghc-9.0.2/site-local/jira-wiki-markup-1.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/jira-wiki-markup-1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jira-wiki-markup
hs-libraries:         HSjira-wiki-markup-1.4.0-39eTg3CIs9iFOsMMa3t1aY
depends:              base-4.15.1.0 mtl-2.2.2 parsec-3.1.14.0 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-jira-wiki-markup/html/jira-wiki-markup.haddock

haddock-html:         /usr/share/doc/haskell-jira-wiki-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
